@@ -354,7 +354,7 @@ namespace libdar
 		    fichier_local dest = fichier_local(get_pointer(), display, gf_write_only, 0700, false, true, false);
 			// the implicit destruction of dest (exiting the block)
 			// will close the 'ret' file descriptor (see ~fichier_local())
-		    ou = ref_fil->get_data(cat_file::normal, nullptr, nullptr);
+		    ou = ref_fil->get_data(cat_file::normal, nullptr, 0, nullptr);
 
 		    try
 		    {
