@@ -106,7 +106,8 @@ namespace libdar
 				  bool delta_diff,          // whether to perform delta diff backup when delta sig is present
 				  bool auto_zeroing_neg_dates,
 				  const std::set<std::string> & ignored_symlinks,
-				  modified_data_detection mod_data_detect);
+				  modified_data_detection mod_data_detect,
+				  const delta_sig_block_size & delta_sig_block_len);
 
     extern void filtre_difference(const std::shared_ptr<user_interaction> & dialog,
 				  const mask &filtre,
@@ -163,7 +164,8 @@ namespace libdar
 			     bool delta_signature,
 			     bool build_delta_sig,
 			     const infinint & delta_sig_min_size,
-			     const mask & delta_mask);
+			     const mask & delta_mask,
+			     const delta_sig_block_size & signature_block_size);
 
 
 	/// initialize variables used for merging in step1 and step2
@@ -219,7 +221,8 @@ namespace libdar
 				   const mask & delta_mask,
 				   bool & abort,
 				   thread_cancellation & thr_cancel,
-				   bool repair_mode);
+				   bool repair_mode,
+				   const delta_sig_block_size & signature_block_size);
 
 
     void filtre_sequentially_read_all_catalogue(catalogue & cat,
