@@ -291,6 +291,7 @@ namespace libdar
 				modified_data_detection mod_data_detect,
 				const infinint & iteration_count,
 				hash_algo kdf_hash,
+				const delta_sig_block_size & sig_block_len,
 				statistics * progressive_report);
 
 	void op_create_in_sub(operation op,                     ///< the filter operation to bind to
@@ -363,6 +364,7 @@ namespace libdar
 			      modified_data_detection mod_data_detect, ///< how to verify data has not changed upon inode metadata change
 			      const infinint & iteration_count, ///< for key derivation
 			      hash_algo kdf_hash,               ///< hash used for key derivation
+			      const delta_sig_block_size & sign_block_len, ///< block len for signature
 			      statistics * st_ptr             ///< statistics must not be nullptr !
 	    );
 
